@@ -103,7 +103,7 @@ void PWScore::Compare(PWScore *pothercore,
        currentPos != GetEntryEndIter();
        currentPos++) {
     // See if user has cancelled
-    if (pbCancel != NULL && *pbCancel) {
+    if (pbCancel != nullptr && *pbCancel) {
       return;
     }
 
@@ -277,7 +277,7 @@ void PWScore::Compare(PWScore *pothercore,
        compPos != pothercore->GetEntryEndIter();
        compPos++) {
     // See if user has cancelled
-    if (pbCancel != NULL && *pbCancel) {
+    if (pbCancel != nullptr && *pbCancel) {
       return;
     }
 
@@ -315,7 +315,7 @@ void PWScore::Compare(PWScore *pothercore,
   } // iteration over other core's element
 
   // See if user has cancelled too late - reset flag so incorrect information not given to user
-  if (pbCancel != NULL && *pbCancel) {
+  if (pbCancel != nullptr && *pbCancel) {
     *pbCancel = false;
   }
 }
@@ -437,7 +437,7 @@ stringT PWScore::Merge(PWScore *pothercore,
        otherPos != pothercore->GetEntryEndIter();
        otherPos++) {
     // See if user has cancelled
-    if (pbCancel != NULL && *pbCancel) {
+    if (pbCancel != nullptr && *pbCancel) {
       delete pmulticmds;
       return _T("");
     }
@@ -624,7 +624,7 @@ stringT PWScore::Merge(PWScore *pothercore,
                        str_diffs.c_str());
 
         // log it
-        if (pRpt != NULL)
+        if (pRpt != nullptr)
           pRpt->WriteLine(strWarnMsg.c_str());
 
         // Check no conflict of unique uuid
@@ -641,7 +641,7 @@ stringT PWScore::Merge(PWScore *pothercore,
                              sxOtherPolicyName, bUpdated,
                              sxMerge_DateTime, IDSC_MERGEPOLICY);
 
-        if (pPolicyCmd != NULL)
+        if (pPolicyCmd != nullptr)
           pmulticmds->Add(pPolicyCmd);
 
         // About to add entry - check keyboard shortcut
@@ -689,7 +689,7 @@ stringT PWScore::Merge(PWScore *pothercore,
                            sxOtherPolicyName, bUpdated,
                            sxMerge_DateTime, IDSC_MERGEPOLICY);
 
-      if (pPolicyCmd != NULL)
+      if (pPolicyCmd != nullptr)
         pmulticmds->Add(pPolicyCmd);
 
       // About to add entry - check keyboard shortcut
@@ -738,7 +738,7 @@ stringT PWScore::Merge(PWScore *pothercore,
   } // iteration over other core's entries
 
   stringT str_results;
-  if (numAdded > 0 && pRpt != NULL) {
+  if (numAdded > 0 && pRpt != nullptr) {
     std::sort(vs_added.begin(), vs_added.end(), MergeSyncGTUCompare);
     stringT str_singular_plural_type, str_singular_plural_verb;
     LoadAString(str_singular_plural_type, numAdded == 1 ? IDSC_ENTRY : IDSC_ENTRIES);
@@ -752,7 +752,7 @@ stringT PWScore::Merge(PWScore *pothercore,
     }
   }
 
-  if (numAliasesAdded > 0 && pRpt != NULL) {
+  if (numAliasesAdded > 0 && pRpt != nullptr) {
     std::sort(vs_AliasesAdded.begin(), vs_AliasesAdded.end(), MergeSyncGTUCompare);
     stringT str_singular_plural_type, str_singular_plural_verb;
     LoadAString(str_singular_plural_type, numAliasesAdded == 1 ? IDSC_ENTRY : IDSC_ENTRIES);
@@ -766,7 +766,7 @@ stringT PWScore::Merge(PWScore *pothercore,
     }
   }
 
-  if (numShortcutsAdded > 0 && pRpt != NULL) {
+  if (numShortcutsAdded > 0 && pRpt != nullptr) {
     std::sort(vs_ShortcutsAdded.begin(), vs_ShortcutsAdded.end(), MergeSyncGTUCompare);
     stringT str_singular_plural_type, str_singular_plural_verb;
     LoadAString(str_singular_plural_type, numShortcutsAdded == 1 ? IDSC_ENTRY : IDSC_ENTRIES);
@@ -781,7 +781,7 @@ stringT PWScore::Merge(PWScore *pothercore,
   }
 
   // See if user has cancelled
-  if (pbCancel != NULL && *pbCancel) {
+  if (pbCancel != nullptr && *pbCancel) {
     delete pmulticmds;
     return _T("");
   }
@@ -808,7 +808,7 @@ stringT PWScore::Merge(PWScore *pothercore,
   Execute(pmulticmds);
 
   // See if user has cancelled too late - reset flag so incorrect information not given to user
-  if (pbCancel != NULL && *pbCancel) {
+  if (pbCancel != nullptr && *pbCancel) {
     *pbCancel = false;
   }
 
@@ -955,7 +955,7 @@ void PWScore::Synchronize(PWScore *pothercore,
        otherPos != pothercore->GetEntryEndIter();
        otherPos++) {
     // See if user has cancelled
-    if (pbCancel != NULL && *pbCancel) {
+    if (pbCancel != nullptr && *pbCancel) {
       delete pmulticmds;
       return;
     }
@@ -1008,7 +1008,7 @@ void PWScore::Synchronize(PWScore *pothercore,
                                    mapRenamedPolicies, vs_PoliciesAdded,
                                    sxValue, bUpdated,
                                    sxSync_DateTime, IDSC_SYNCPOLICY);
-            if (pPolicyCmd != NULL)
+            if (pPolicyCmd != nullptr)
               pmulticmds->Add(pPolicyCmd);
           } else {
             if (sxValue != updItem.GetFieldValue(static_cast<CItemData::FieldType>(i))) {
@@ -1040,7 +1040,7 @@ void PWScore::Synchronize(PWScore *pothercore,
   } // iteration over other core's entries
 
   stringT str_results;
-  if (numUpdated > 0 && pRpt != NULL) {
+  if (numUpdated > 0 && pRpt != nullptr) {
     std::sort(vs_updated.begin(), vs_updated.end(), MergeSyncGTUCompare);
     stringT str_singular_plural_type, str_singular_plural_verb;
     LoadAString(str_singular_plural_type, numUpdated == 1 ? IDSC_ENTRY : IDSC_ENTRIES);
@@ -1055,7 +1055,7 @@ void PWScore::Synchronize(PWScore *pothercore,
   }
 
   // See if user has cancelled
-  if (pbCancel != NULL && *pbCancel) {
+  if (pbCancel != nullptr && *pbCancel) {
     delete pmulticmds;
     ResumeOnDBNotification();
     return;
@@ -1070,7 +1070,7 @@ void PWScore::Synchronize(PWScore *pothercore,
   ResumeOnDBNotification();
 
   // See if user has cancelled too late - reset flag so incorrect information not given to user
-  if (pbCancel != NULL && *pbCancel) {
+  if (pbCancel != nullptr && *pbCancel) {
     *pbCancel = false;
     return;
   }
@@ -1088,7 +1088,7 @@ Command *PWScore::ProcessPolicyName(PWScore *pothercore, CItemData &updtEntry,
                                     StringX &sxOtherPolicyName, bool &bUpdated,
                                     const StringX &sxDateTime, const UINT &IDS_MESSAGE)
 {
-  Command *pcmd(NULL);
+  Command *pcmd(nullptr);
 
   if (sxOtherPolicyName.empty()) {
     // If now blank, meaning default, are the defaults the same?
@@ -1111,7 +1111,7 @@ Command *PWScore::ProcessPolicyName(PWScore *pothercore, CItemData &updtEntry,
 
     if (!bInFrom) {
       ASSERT(bInFrom); // Problem if set but not there!
-      return NULL;
+      return nullptr;
     }
 
     if (bInTo) {
