@@ -13,7 +13,7 @@ PWSfileHeader::PWSfileHeader()
     m_prefString(_T("")), m_whenlastsaved(0),
     m_lastsavedby(_T("")), m_lastsavedon(_T("")),
     m_whatlastsaved(_T("")),
-    m_DB_Name(_T("")), m_DB_Description(_T("")), m_yubi_sk(NULL)
+    m_DB_Name(_T("")), m_DB_Description(_T("")), m_yubi_sk(nullptr)
 {
 }
 
@@ -28,11 +28,11 @@ PWSfileHeader::PWSfileHeader(const PWSfileHeader &h)
     m_whatlastsaved(h.m_whatlastsaved),
     m_DB_Name(h.m_DB_Name), m_DB_Description(h.m_DB_Description), m_RUEList(h.m_RUEList)
 {
-  if (h.m_yubi_sk != NULL) {
+  if (h.m_yubi_sk != nullptr) {
     m_yubi_sk = new unsigned char[YUBI_SK_LEN];
     memcpy(m_yubi_sk, h.m_yubi_sk, YUBI_SK_LEN);
   } else {
-    m_yubi_sk = NULL;
+    m_yubi_sk = nullptr;
   }
 }
 
@@ -58,14 +58,14 @@ PWSfileHeader &PWSfileHeader::operator=(const PWSfileHeader &h)
     m_DB_Name = h.m_DB_Name;
     m_DB_Description = h.m_DB_Description;
     m_RUEList = h.m_RUEList;
-    if (h.m_yubi_sk != NULL) {
+    if (h.m_yubi_sk != nullptr) {
       if (m_yubi_sk)
         trashMemory(m_yubi_sk, YUBI_SK_LEN);
       delete[] m_yubi_sk;
       m_yubi_sk = new unsigned char[YUBI_SK_LEN];
       memcpy(m_yubi_sk, h.m_yubi_sk, YUBI_SK_LEN);
     } else {
-      m_yubi_sk = NULL;
+      m_yubi_sk = nullptr;
     }
   }
   return *this;
@@ -87,11 +87,11 @@ bool PWSfileHeader::operator==(const PWSfileHeader &h) const
                  m_RUEList == h.m_RUEList);
   if (!retval)
     return false;
-  if (m_yubi_sk == NULL && h.m_yubi_sk == NULL)
+  if (m_yubi_sk == nullptr && h.m_yubi_sk == nullptr)
     return true;
-  if ((m_yubi_sk == NULL && h.m_yubi_sk != NULL) ||
-      (m_yubi_sk != NULL && h.m_yubi_sk == NULL))
+  if ((m_yubi_sk == nullptr && h.m_yubi_sk != nullptr) ||
+      (m_yubi_sk != nullptr && h.m_yubi_sk == nullptr))
     return false;
-  // here iff both m_yubi_sk's != NULL
+  // here iff both m_yubi_sk's != nullptr
   return (memcmp(m_yubi_sk, h.m_yubi_sk, YUBI_SK_LEN) == 0);
 }
