@@ -19,7 +19,7 @@ class PWSfileV1V2 : public PWSfile
 {
 public:
   static int CheckPasskey(const StringX &filename,
-                          const StringX &passkey, FILE *a_fd = NULL);
+                          const StringX &passkey, FILE *a_fd = nullptr);
 
   PWSfileV1V2(const StringX &filename, RWmode mode, VERSION version);
   ~PWSfileV1V2();
