@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2016 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2018 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -48,7 +48,7 @@ template<class T> void ToUpper(T &s)
 template<class T> T &Trim(T &s, const TCHAR *set)
 {
   const TCHAR *ws = _T(" \t\r\n");
-  const TCHAR *tset = (set == NULL) ? ws : set;
+  const TCHAR *tset = (set == nullptr) ? ws : set;
 
   typename T::size_type b = s.find_first_not_of(tset);
   if (b == T::npos) {
@@ -64,7 +64,7 @@ template<class T> T &Trim(T &s, const TCHAR *set)
 template<class T> T &TrimRight(T &s, const TCHAR *set)
 {
   const TCHAR *ws = _T(" \t\r\n");
-  const TCHAR *tset = (set == NULL) ? ws : set;
+  const TCHAR *tset = (set == nullptr) ? ws : set;
 
   typename T::size_type e = s.find_last_not_of(tset);
   if (e == T::npos) {
@@ -79,7 +79,7 @@ template<class T> T &TrimRight(T &s, const TCHAR *set)
 template<class T> T &TrimLeft(T &s, const TCHAR *set)
 {
   const TCHAR *ws = _T(" \t\r\n");
-  const TCHAR *tset = (set == NULL) ? ws : set;
+  const TCHAR *tset = (set == nullptr) ? ws : set;
 
   typename T::size_type b = s.find_first_not_of(tset);
   if (b == T::npos) {
@@ -196,7 +196,6 @@ template<class T> void Format(T &s, int fmt, ...)
   va_end(args);
 }
 
-
 // instantiations for StringX & stringT
 template int CompareNoCase(const StringX &s1, const StringX &s2);
 template int CompareNoCase(const stringT &s1, const stringT &s2);
