@@ -130,6 +130,10 @@ public:
 
 ////@end CManagePasswordPolicies event handler declarations
 
+  void OnSize(wxSizeEvent& event);
+  
+  void OnMaximize(wxMaximizeEvent& event);
+
 ////@begin CManagePasswordPolicies member function declarations
 
   /// Retrieves bitmap resources
@@ -155,11 +159,12 @@ public:
  private:
   void UpdateNames();
   void UpdateDetails();
-  void UpdatePolicy(const wxString &polname, const PWPolicy &pol, CPP_FLAGS mode); // called after New/Edit
+  void UpdatePolicy(const wxString &polname, const PWPolicy &pol, st_PSWDPolicyChange::Mode mode); // called after New/Edit
   void ShowPolicyDetails();
   void ShowPolicyEntries();
   PWPolicy GetSelectedPolicy() const;
   int GetSelectedRow() const;
+  void ResizeGridColumns();
 
   PWScore &m_core;
   // History of current changes for Undo/Redo and index to current change
@@ -178,6 +183,8 @@ public:
   bool m_bViewPolicy;
   
   bool m_bUndoShortcut, m_bRedoShortcut;
+  
+  int m_ScrollbarWidth;
 };
 
 #endif
